==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga2c02b8445a0b90109ff9943ec8e93b49",
"group__API__Data__Interfaces.html#ga08bed7d1e9b7cb2b2b76932eb9c33353",
"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a",
"group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5",
"group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70",
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27",
"group__API__Perf__Monitoring.html#ggab66267d03f0557b14cc3ec0c24c01ebaa99c605ec09b32e1cce0ba51df5081f1d",
"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21",
"group__API__Standard__Memory__Library.html#ga864a3b576a56d686010cfd6c9d5ef14b",
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html",
"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html",
"starpu__bound_8h.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.5-2.src.tar.zst: starpu-1.4.5/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "A Vector Scaling Application", "VectorApplication.html", [
      [ "Base version", "VectorApplication.html#BaseVersion", null ],
      [ "StarPU C version", "VectorApplication.html#StarPUCversion", [
        [ "Computation Kernels", "VectorApplication.html#ComputationKernels", null ],
        [ "Main Code", "VectorApplication.html#MainCode", null ]
      ] ],
      [ "Building and Running", "VectorApplication.html#BuildingandRunning", null ]
    ] ],
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ],
      [ "Running the application", "StencilApplication.html#StencilRunning", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga18bec8430309a613520d6042d701790d",
"group__API__Data__Interfaces.html#ga0022c371e342ac366720c7735f4be3be",
"group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792",
"group__API__Initialization__and__Termination.html#a304d0919a6a77fe0239291a4fb40d9dc",
"group__API__MPI__Support.html#ga53f16983c6e100ed0e0e129325ddbf40",
"group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c",
"group__API__Perf__Monitoring.html#gae9960277a9e4f22f8000ba34aa6afc42",
"group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514",
"group__API__Standard__Memory__Library.html#ga4e9089680daf0b2d7f26e4657ffe9f48",
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dac8fa4358a1bbed68129ebc834ee32bc1",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html",
"interfacefstarpu__mod_1_1fstarpu__task__get__current.html",
"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
